#! /bin/bash

# This script determines if the external data manager for MSU
# data loading is running or not.  If the external data manager is not
# running, the external data manager is started.  This script file is going
# to run as a cron job at a test cell to ensure the ExternalDataManager is
# always running for MSU Data Loading.
#
# Usage: /cyflex/cmds/check_msu_loading
#
# Author: Jennifer Schuck
# 
# History
#   05/14/2020 - Jennifer Schuck - Initial release.


#  This file is to:
#     - determine if the ExternalDataManager instance for MSU Loading
#       is running
#       - if is running
#         - do nothing
#       - if is not running 
#         - start instance

# Determine if ExternalDataManager Instance for MSU Loading is Running

PROG=com.cybermetrix.cyflex.extdatman.ExternalDataManager
FILE=/specs/extdatman.cummins.msu

# Find the PID for the MSU data loading process.
PID=$(ps -ef | grep $PROG | grep $FILE | grep -v grep | tr -s ' ' | cut -f2 -d\ )

# If MSU data loading isn't running, start it
if [ "$PID" = "" ]; then

   # start MSU Data Loading
   
   DATE=`date +"%y%m%d"`
   exec /cyflex/cmds/extdatman.cummins.msu >> /data/errors/extdatman.msu.$DATE 2>>/data/errors/extdatman.msu.errs.$DATE &
fi
